@@ -42,12 +42,12 @@ FILE *ddbg;
 #endif
 
 // extern variables from AudMeS.cpp
-extern short *g_OscBuffer_Left;
-extern short *g_OscBuffer_Right;
+extern float *g_OscBuffer_Left;
+extern float *g_OscBuffer_Right;
 extern long int g_OscBufferPosition;
 
-extern short *g_SpeBuffer_Left;
-extern short *g_SpeBuffer_Right;
+extern float *g_SpeBuffer_Left;
+extern float *g_SpeBuffer_Right;
 extern long int g_SpeBufferPosition;
 
 extern int g_OscBufferChanged;
@@ -67,11 +67,18 @@ bool lfsr16() {
   return bit;
 }
 
+/*
+ * callback function to catch runtime errors
+ */
+void catcherr(RtAudioError::Type WXUNUSED(type), const std::string &errorText) {
+  std::cerr << '\n' << errorText << '\n' << std::endl;
+}
+
 /*
  * callback function to fetch audio input and generate tones
  */
 int inout(void *outputBuffer, void *inputBuffer, unsigned int nBufferFrames,
-          double WXUNUSED(streamTime), RtAudioStreamStatus WXUNUSED(status), void *data) {
+          double WXUNUSED(streamTime), RtAudioStreamStatus status, void *data) {
 #ifdef _DEBUG
   fprintf(ddbg, "Jsme tady ");
 #endif
@@ -79,6 +86,8 @@ int inout(void *outputBuffer, void *inputBuffer, unsigned int nBufferFrames,
   RWAudio *aRWAudioClass = (RWAudio *)data;
   unsigned long i;
 
+  if (status) std::cerr << "Audio stream over/underflow detected." << std::endl;
+
   // copy input buffer into two L/R channels
   if (0 != aRWAudioClass->m_Buflen_Changed) {
     aRWAudioClass->m_Buflen_Changed = 0;
@@ -88,13 +97,13 @@ int inout(void *outputBuffer, void *inputBuffer, unsigned int nBufferFrames,
     free(g_SpeBuffer_Right);
     g_OscBufferPosition = 0;
     g_SpeBufferPosition = 0;
-    g_OscBuffer_Left = (short *)malloc(aRWAudioClass->m_OscBufferLen * sizeof(short));
-    g_OscBuffer_Right = (short *)malloc(aRWAudioClass->m_OscBufferLen * sizeof(short));
-    g_SpeBuffer_Left = (short *)malloc(aRWAudioClass->m_SpeBufferLen * sizeof(short));
-    g_SpeBuffer_Right = (short *)malloc(aRWAudioClass->m_SpeBufferLen * sizeof(short));
+    g_OscBuffer_Left = (float *)malloc(aRWAudioClass->m_OscBufferLen * sizeof(float));
+    g_OscBuffer_Right = (float *)malloc(aRWAudioClass->m_OscBufferLen * sizeof(float));
+    g_SpeBuffer_Left = (float *)malloc(aRWAudioClass->m_SpeBufferLen * sizeof(float));
+    g_SpeBuffer_Right = (float *)malloc(aRWAudioClass->m_SpeBufferLen * sizeof(float));
   }
 
-  short *inBuf = (short *)inputBuffer;
+  float *inBuf = (float *)inputBuffer;
 
   // make a copy for oscilloscope
   if (0 == g_OscBufferChanged) {
@@ -113,7 +122,7 @@ int inout(void *outputBuffer, void *inputBuffer, unsigned int nBufferFrames,
     }
   }
 
-  inBuf = (short *)inputBuffer;
+  inBuf = (float *)inputBuffer;
   // make a copy for spectrum analyzer
   if (0 == g_SpeBufferChanged) {
     for (i = 0; i < nBufferFrames; i++) {
@@ -132,7 +141,7 @@ int inout(void *outputBuffer, void *inputBuffer, unsigned int nBufferFrames,
   }
 
   // fill output buffer
-  short *outBuf = (short *)outputBuffer;
+  float *outBuf = (float *)outputBuffer;
 
 #ifdef _DEBUG
   fprintf(ddbg, "\n Frames: %d\n ", nBufferFrames);
@@ -213,11 +222,11 @@ int inout(void *outputBuffer, void *inputBuffer, unsigned int nBufferFrames,
     if ((2.0 * M_PI) < aRWAudioClass->m_genFI_l) aRWAudioClass->m_genFI_l -= 2.0 * M_PI;
     if ((2.0 * M_PI) < aRWAudioClass->m_genFI_r) aRWAudioClass->m_genFI_r -= 2.0 * M_PI;
 
-    *outBuf++ = (short)(32768.f * aRWAudioClass->m_genGain_l * y);
-    *outBuf++ = (short)(32768.f * aRWAudioClass->m_genGain_r * y2);
+    *outBuf++ = (float)(aRWAudioClass->m_genGain_l * y);
+    *outBuf++ = (float)(aRWAudioClass->m_genGain_r * y2);
 
 #ifdef _DEBUG
-    // fprintf(ddbg,"%04X %04X ",(short)(32768.f * y), (short)(32768.f * y2));
+    // fprintf(ddbg,"%04X %04X ",(float)(32768.f * y), (float)(32768.f * y2));
 #endif
   }
   return 0;
@@ -247,10 +256,11 @@ int RWAudio::InitSnd(long int oscbuflen, long int spebuflen, std::string &rtinfo
 
   g_OscBufferPosition = 0;
   g_SpeBufferPosition = 0;
-  g_OscBuffer_Left = (short *)malloc(m_OscBufferLen * sizeof(short));
-  g_OscBuffer_Right = (short *)malloc(m_OscBufferLen * sizeof(short));
-  g_SpeBuffer_Left = (short *)malloc(m_SpeBufferLen * sizeof(short));
-  g_SpeBuffer_Right = (short *)malloc(m_SpeBufferLen * sizeof(short));
+
+  g_OscBuffer_Left = (float *)malloc(m_OscBufferLen * sizeof(float));
+  g_OscBuffer_Right = (float *)malloc(m_OscBufferLen * sizeof(float));
+  g_SpeBuffer_Left = (float *)malloc(m_SpeBufferLen * sizeof(float));
+  g_SpeBuffer_Right = (float *)malloc(m_SpeBufferLen * sizeof(float));
 
   RtAudio::DeviceInfo info;
   unsigned int devices;
@@ -311,11 +321,11 @@ int RWAudio::RestartAudio(int recDevId, int playDevId) {
   iParams.firstChannel = 0;
   oParams.firstChannel = 0;
 
-  // rtAOptions.flags |= RTAUDIO_NONINTERLEAVED;
+  rtAOptions.flags = 0;
 
   try {
-    m_AudioDriver.openStream(&oParams, &iParams, RTAUDIO_SINT16, m_sampleRate, &bufferFrames,
-                             &inout, (void *)this);  //, &rtAOptions );
+    m_AudioDriver.openStream(&oParams, &iParams, RTAUDIO_FLOAT32, m_sampleRate, &bufferFrames,
+                             &inout, (void *)this, &rtAOptions, &catcherr);
   } catch (RtAudioError &e) {
     // std::cerr << '\n' << e.getMessage() << '\n' << std::endl;
     return 1;
